@@ -122,7 +122,30 @@ getPools<- function(token, start_year, end_year, arthropod, agency_ids = NULL){
   pools$pool_longitude <- do.call(rbind, lapply(pools$location_shape_coordinates, function(x) unlist(x)))[,1]
   pools$pool_latitude <- do.call(rbind, lapply(pools$location_shape_coordinates, function(x) unlist(x)))[,2]
 
-  pools=pools%>%select(pool_id,pool_num,agency_id,agency_code,agency_name,site_id,site_code,site_name,pool_longitude, pool_longitude,pool_latitude,primary_source,collection,pool_comments,
+
+  sites = getSites(token)
+  sites_zip = sites[c("id", "city", "postal_code", "region")] #selects the columns with relevant information, this can be changed of course
+  regions = getRegions(token)
+  colnames(sites_zip)[1] = "site_id" #rename for join function
+
+  pool_site = inner_join(pools, sites_zip, by = 'site_id') #join site information to collections
+  regions_county = regions[c("id","parent","type","geoid", "namelsad")] #select id and county name
+  colnames(regions_county)[1] = "region" #rename for join function
+  pools = inner_join(pool_site, regions_county, by = "region")
+
+  pools=pools %>%
+    mutate(namelsad = if_else(!(type %in% c("state","county")),
+                              # For geoid > 5, join and update 'namelsad'
+                              left_join(., regions %>% select(id, namelsad), by = c("parent" = "id")) %>%
+                                mutate(namelsad = coalesce(namelsad.y, namelsad.x)) %>%
+                                pull(namelsad),
+                              # For geoid <= 5, keep the original 'namelsad'
+                              namelsad))
+
+
+  colnames(pools)[which(names(pools) == "namelsad")] <- "county"
+
+  pools=pools%>%select(pool_id,pool_num,agency_id,agency_code,agency_name,site_id,site_code,site_name,pool_longitude, pool_longitude,pool_latitude,city,postal_code, county,geoid,primary_source,collection,pool_comments,
                  surv_year,collection_date,species_display_name,species_full_name,sex_type,sex_name,trap_acronym,trap_name,trap_presence,num_count,test_id,value,test_date,
                  method_name,method_acronym,target_acronym,target_vector,
                  target_icd_10,status_name,test_agency_name,test_agency_code,test_agency_state_acronym, add_date ,updated)
